
![st_deta_connections](https://github.com/mohitrajsinha/st_deta_connection/assets/112544299/8ff92d08-f333-41a7-a2ec-7f8daf2d5da8)

# Streamlit Deta Connection Module

## Overview

This module provides a Streamlit connection to Deta Base, allowing users to easily fetch , insert and cache data from Deta Base collections in a Streamlit app.

## Prerequisites
Set up your Deta Base credentials:
- Obtain your Deta Base project key from https://deta.sh
- Create a `secrets.toml` file in the `.streamlit` folder of your root directory of the project.
- Insert `data_key=YOUR_PROJECT_KEY`

```bash
pip install -r requirements.txt
```
## Installation

You can install the module using the following pip command:

```bash
pip install st_deta_connection
